# censusdis

A package for applying diversity, integration, and segregation metrics
to U.S. Census demographic data. See the [divintseg](https://github.com/vengroff/divintseg/) 
project for more information on these metrics.

[![Hippocratic License HL3-CL-ECO-EXTR-FFD-LAW-MIL-SV](https://img.shields.io/static/v1?label=Hippocratic%20License&message=HL3-CL-ECO-EXTR-FFD-LAW-MIL-SV&labelColor=5e2751&color=bc8c3d)](https://firstdonoharm.dev/version/3/0/cl-eco-extr-ffd-law-mil-sv.html)
